const path = require("path");
const querystring = require("querystring");
const express = require("express");
const cors = require("cors");
const axios = require("axios");

const HTTP_PORT = 8010;

const app = express();
app.use(express.static(path.join(__dirname, "web")));
app.use(express.text({ type: "*/*" }));
app.use(cors());
app.set("views", path.join(__dirname, "web"));

app.post("/submitForm", (request, response) => {
    const parsed = querystring.parse(request.body);
    const endpointCreate = `${parsed.forsakringskassan}/public/v1/erakning/create?kanal=1`;
    const endpointCreatePayload = {
        forsakringskassan: parsed.forsakringskassan,
        token: parsed.token,
        returnUrl: parsed.returnUrl,
        signalUrl: parsed.signalUrl,
        systemleverantorNamn: parsed.systemleverantorNamn,
        erakning: JSON.parse(parsed.erakning),
    };

    console.log(
        `Anropar:\n${endpointCreate}\n\n${JSON.stringify(
            endpointCreatePayload,
            null,
            4,
        )}\n\n`,
    );
    axios
        .post(endpointCreate, endpointCreatePayload)
        .then((responseCreate) => {
            console.log(
                `Svarade:\n${responseCreate.status}`,
                responseCreate.data,
            );

            const fingerprint = responseCreate.data.fingerprint;
            if (!fingerprint) {
                throw Error(`Fick inget fingerprint`);
            }
            const endpointStart = `${parsed.forsakringskassan}/public/v1/erakning/start?kanal=1&fingerprint=${fingerprint}`;
            console.log(`Svarar med redirect till:\n${endpointStart}`);
            response.redirect(endpointStart);
        })
        .catch((errorCreate) => {
            console.log(`Fel!`);
            if (errorCreate.response) {
                console.log(errorCreate.response.data);
                console.log(errorCreate.response.status);
                console.log(errorCreate.response.headers);
            } else {
                console.log(errorCreate);
            }
            response.sendStatus(400);
        });
});

app.listen(HTTP_PORT, () => {
    // eslint-disable-next-line
    console.log(`Server listening on port: ${HTTP_PORT}.`);
});
